==> rezdy_api_for_suppliers_client-1.0.0.tar.gz: rezdy_api_for_suppliers_client-1.0.0/rezdy_api_for_suppliers_client/api/categories/get_category.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...types import Response


def _get_kwargs(
    category_id: int,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/categories/{categoryId}".format(client.base_url, categoryId=category_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    category_id: int,
    *,
    client: Client,
) -> Response[Any]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        category_id=category_id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    category_id: int,
    *,
    client: Client,
) -> Response[Any]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        category_id=category_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)

==> rezdy_api_for_suppliers_client-1.0.1.tar.gz: rezdy_api_for_suppliers_client-1.0.1/rezdy_api_for_suppliers_client/api/categories/get_category.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.response_category import ResponseCategory
from ...types import Response


def _get_kwargs(
    category_id: int,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/categories/{categoryId}".format(client.base_url, categoryId=category_id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[ResponseCategory]:
    if response.status_code == 200:
        response_200 = ResponseCategory.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[ResponseCategory]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    category_id: int,
    *,
    client: Client,
) -> Response[ResponseCategory]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[ResponseCategory]
    """

    kwargs = _get_kwargs(
        category_id=category_id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    category_id: int,
    *,
    client: Client,
) -> Optional[ResponseCategory]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[ResponseCategory]
    """

    return sync_detailed(
        category_id=category_id,
        client=client,
    ).parsed


async def asyncio_detailed(
    category_id: int,
    *,
    client: Client,
) -> Response[ResponseCategory]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[ResponseCategory]
    """

    kwargs = _get_kwargs(
        category_id=category_id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    category_id: int,
    *,
    client: Client,
) -> Optional[ResponseCategory]:
    """Get category

     Load an existing category by Id

    Args:
        category_id (int):

    Returns:
        Response[ResponseCategory]
    """

    return (
        await asyncio_detailed(
            category_id=category_id,
            client=client,
        )
    ).parsed
